@@ -10,7 +10,6 @@
 # License: MIT
 #
 
-import functools
 import sys
 import unittest
 import warnings
@@ -36,7 +35,7 @@ def noop(*args, **kwargs):
     return
 
 
-def hasAnsiEscapeCodes(s):
+def has_ansi_escape_codes(s):
     # Oversimplified, but ¯\_(ツ)_/¯. TODO(grun): Test with regex.
     return '\x1b[' in s
 
@@ -51,7 +50,7 @@ class FakeTeletypeBuffer(StringIO):
 
 
 @contextmanager
-def disableColoring():
+def disable_coloring():
     originalOutputFunction = ic.outputFunction
 
     ic.configureOutput(outputFunction=stderrPrint)
@@ -60,7 +59,7 @@ def disableColoring():
 
 
 @contextmanager
-def configureIcecreamOutput(prefix=None, outputFunction=None,
+def configure_icecream_output(prefix=None, outputFunction=None,
                             argToStringFunction=None, includeContext=None,
                             contextAbsPath=None):
     oldPrefix = ic.prefix
@@ -88,7 +87,7 @@ def configureIcecreamOutput(prefix=None, outputFunction=None,
 
 
 @contextmanager
-def captureStandardStreams():
+def capture_standard_streams():
     realStdout = sys.stdout
     realStderr = sys.stderr
     newStdout = FakeTeletypeBuffer()
@@ -102,24 +101,24 @@ def captureStandardStreams():
         sys.stderr = realStderr
 
 
-def stripPrefix(line):
+def strip_prefix(line):
     if line.startswith(ic.prefix):
         line = line.strip()[len(ic.prefix):]
     return line
 
 
-def lineIsContextAndTime(line):
-    line = stripPrefix(line)  # ic| f.py:33 in foo() at 08:08:51.389
+def line_is_context_and_time(line):
+    line = strip_prefix(line)  # ic| f.py:33 in foo() at 08:08:51.389
     context, time = line.split(' at ')
 
     return (
-        lineIsContext(context) and
+        line_is_context(context) and
         len(time.split(':')) == 3 and
         len(time.split('.')) == 2)
 
 
-def lineIsContext(line):
-    line = stripPrefix(line)  # ic| f.py:33 in foo()
+def line_is_context(line):
+    line = strip_prefix(line)  # ic| f.py:33 in foo()
     sourceLocation, function = line.split(' in ')  # f.py:33 in foo()
     filename, lineNumber = sourceLocation.split(':')  # f.py:33
     name, ext = splitext(filename)
@@ -130,8 +129,8 @@ def lineIsContext(line):
         name == splitext(MY_FILENAME)[0] and
         (function == '<module>' or function.endswith('()')))
 
-def lineIsAbsPathContext(line):
-    line = stripPrefix(line)  # ic| /absolute/path/to/f.py:33 in foo()
+def line_is_abs_path_context(line):
+    line = strip_prefix(line)  # ic| /absolute/path/to/f.py:33 in foo()
     sourceLocation, function = line.split(' in ')  # /absolute/path/to/f.py:33 in foo()
     filepath, lineNumber = sourceLocation.split(':')  # /absolute/path/to/f.py:33
     path, ext = splitext(filepath)
@@ -142,7 +141,7 @@ def lineIsAbsPathContext(line):
         path == splitext(MY_FILEPATH)[0] and
         (function == '<module>' or function.endswith('()')))
 
-def lineAfterContext(line, prefix):
+def line_after_context(line, prefix):
     if line.startswith(prefix):
         line = line[len(prefix):]
 
@@ -153,9 +152,8 @@ def lineAfterContext(line, prefix):
 
     return line
 
-
-def parseOutputIntoPairs(out, err, assertNumLines,
-                         prefix=icecream.DEFAULT_PREFIX):
+def parse_output_into_pairs(out, err, assert_num_lines,
+                            prefix=icecream.DEFAULT_PREFIX):
     if isinstance(out, StringIO):
         out = out.getvalue()
     if isinstance(err, StringIO):
@@ -164,42 +162,42 @@ def parseOutputIntoPairs(out, err, assertNumLines,
     assert not out
 
     lines = err.splitlines()
-    if assertNumLines:
-        assert len(lines) == assertNumLines
+    if assert_num_lines:
+        assert len(lines) == assert_num_lines
 
-    linePairs = []
+    line_pairs = []
     for line in lines:
-        line = lineAfterContext(line, prefix)
+        line = line_after_context(line, prefix)
 
         if not line:
-            linePairs.append([])
+            line_pairs.append([])
             continue
 
         pairStrs = line.split(TEST_PAIR_DELIMITER)
         pairs = [tuple(s.split(':', 1)) for s in pairStrs]
         # Indented line of a multiline value.
         if len(pairs[0]) == 1 and line.startswith(' '):
-            arg, value = linePairs[-1][-1]
+            arg, value = line_pairs[-1][-1]
             looksLikeAString = value[0] in ["'", '"']
             prefix = ((arg + ': ' if arg is not None else '')  # A multiline value
                       + (' ' if looksLikeAString else ''))
             dedented = line[len(ic.prefix) + len(prefix):]
-            linePairs[-1][-1] = (arg, value + '\n' + dedented)
+            line_pairs[-1][-1] = (arg, value + '\n' + dedented)
         else:
             items = [
                 (None, p[0].strip()) if len(p) == 1  # A value, like ic(3).
                 else (p[0].strip(), p[1].strip())  # A variable, like ic(a).
                 for p in pairs]
-            linePairs.append(items)
+            line_pairs.append(items)
 
-    return linePairs
+    return line_pairs
 
 
 class TestIceCream(unittest.TestCase):
     def setUp(self):
         ic._pairDelimiter = TEST_PAIR_DELIMITER
 
-    def testMetadata(self):
+    def test_metadata(self):
         def is_non_empty_string(s):
             return isinstance(s, str) and s
         assert is_non_empty_string(icecream.__title__)
@@ -210,160 +208,160 @@ class TestIceCream(unittest.TestCase):
         assert is_non_empty_string(icecream.__description__)
         assert is_non_empty_string(icecream.__url__)
 
-    def testWithoutArgs(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_without_args(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic()
-        assert lineIsContextAndTime(err.getvalue())
+        assert line_is_context_and_time(err.getvalue())
 
-    def testAsArgument(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_as_argument(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             noop(ic(a), ic(b))
-        pairs = parseOutputIntoPairs(out, err, 2)
+        pairs = parse_output_into_pairs(out, err, 2)
         assert pairs[0][0] == ('a', '1') and pairs[1][0] == ('b', '2')
 
-        with disableColoring(), captureStandardStreams() as (out, err):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             dic = {1: ic(a)}  # noqa
             lst = [ic(b), ic()]  # noqa
-        pairs = parseOutputIntoPairs(out, err, 3)
+        pairs = parse_output_into_pairs(out, err, 3)
         assert pairs[0][0] == ('a', '1')
         assert pairs[1][0] == ('b', '2')
-        assert lineIsContextAndTime(err.getvalue().splitlines()[-1])
+        assert line_is_context_and_time(err.getvalue().splitlines()[-1])
 
-    def testSingleArgument(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_single_argument(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic(a)
-        assert parseOutputIntoPairs(out, err, 1)[0][0] == ('a', '1')
+        assert parse_output_into_pairs(out, err, 1)[0][0] == ('a', '1')
 
-    def testMultipleArguments(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_multiple_arguments(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic(a, b)
-        pairs = parseOutputIntoPairs(out, err, 1)[0]
+        pairs = parse_output_into_pairs(out, err, 1)[0]
         assert pairs == [('a', '1'), ('b', '2')]
 
-    def testNestedMultiline(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_nested_multiline(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic(
                 )
-        assert lineIsContextAndTime(err.getvalue())
+        assert line_is_context_and_time(err.getvalue())
 
-        with disableColoring(), captureStandardStreams() as (out, err):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic(a,
                'foo')
-        pairs = parseOutputIntoPairs(out, err, 1)[0]
+        pairs = parse_output_into_pairs(out, err, 1)[0]
         assert pairs == [('a',  '1'), (None, "'foo'")]
 
-        with disableColoring(), captureStandardStreams() as (out, err):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             noop(noop(noop({1: ic(
                 noop())})))
-        assert parseOutputIntoPairs(out, err, 1)[0][0] == ('noop()', 'None')
+        assert parse_output_into_pairs(out, err, 1)[0][0] == ('noop()', 'None')
 
-    def testExpressionArguments(self):
+    def test_expression_arguments(self):
         class klass():
             attr = 'yep'
         d = {'d': {1: 'one'}, 'k': klass}
 
-        with disableColoring(), captureStandardStreams() as (out, err):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic(d['d'][1])
-        pair = parseOutputIntoPairs(out, err, 1)[0][0]
+        pair = parse_output_into_pairs(out, err, 1)[0][0]
         assert pair == ("d['d'][1]", "'one'")
 
-        with disableColoring(), captureStandardStreams() as (out, err):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic(d['k'].attr)
-        pair = parseOutputIntoPairs(out, err, 1)[0][0]
+        pair = parse_output_into_pairs(out, err, 1)[0][0]
         assert pair == ("d['k'].attr", "'yep'")
 
-    def testMultipleCallsOnSameLine(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_multiple_calls_on_same_line(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic(a); ic(b, c)  # noqa
-        pairs = parseOutputIntoPairs(out, err, 2)
+        pairs = parse_output_into_pairs(out, err, 2)
         assert pairs[0][0] == ('a', '1')
         assert pairs[1] == [('b', '2'), ('c', '3')]
 
-    def testCallSurroundedByExpressions(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_call_surrounded_by_expressions(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             noop(); ic(a); noop()  # noqa
-        assert parseOutputIntoPairs(out, err, 1)[0][0] == ('a', '1')
+        assert parse_output_into_pairs(out, err, 1)[0][0] == ('a', '1')
 
-    def testComments(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_comments(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             """Comment."""; ic(); # Comment.  # noqa
-        assert lineIsContextAndTime(err.getvalue())
+        assert line_is_context_and_time(err.getvalue())
 
-    def testMethodArguments(self):
+    def test_method_arguments(self):
         class Foo:
             def foo(self):
                 return 'foo'
         f = Foo()
-        with disableColoring(), captureStandardStreams() as (out, err):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic(f.foo())
-        assert parseOutputIntoPairs(out, err, 1)[0][0] == ('f.foo()', "'foo'")
+        assert parse_output_into_pairs(out, err, 1)[0][0] == ('f.foo()', "'foo'")
 
-    def testComplicated(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_complicated(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             noop(); ic(); noop(); ic(a,  # noqa
                                      b, noop.__class__.__name__,  # noqa
                                          noop ()); noop()  # noqa
-        pairs = parseOutputIntoPairs(out, err, 2)
-        assert lineIsContextAndTime(err.getvalue().splitlines()[0])
+        pairs = parse_output_into_pairs(out, err, 2)
+        assert line_is_context_and_time(err.getvalue().splitlines()[0])
         assert pairs[1] == [
             ('a', '1'), ('b', '2'), ('noop.__class__.__name__', "'function'"),
             ('noop ()', 'None')]
 
-    def testReturnValue(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_return_value(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             assert ic() is None
             assert ic(1) == 1
             assert ic(1, 2, 3) == (1, 2, 3)
 
-    def testDifferentName(self):
+    def test_different_name(self):
         from icecream import ic as foo
-        with disableColoring(), captureStandardStreams() as (out, err):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             foo()
-        assert lineIsContextAndTime(err.getvalue())
+        assert line_is_context_and_time(err.getvalue())
 
         newname = foo
-        with disableColoring(), captureStandardStreams() as (out, err):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             newname(a)
-        pair = parseOutputIntoPairs(out, err, 1)[0][0]
+        pair = parse_output_into_pairs(out, err, 1)[0][0]
         assert pair == ('a', '1')
 
-    def testPrefixConfiguration(self):
+    def test_prefix_configuration(self):
         prefix = 'lolsup '
-        with configureIcecreamOutput(prefix, stderrPrint):
-            with disableColoring(), captureStandardStreams() as (out, err):
+        with configure_icecream_output(prefix, stderrPrint):
+            with disable_coloring(), capture_standard_streams() as (out, err):
                 ic(a)
-        pair = parseOutputIntoPairs(out, err, 1, prefix=prefix)[0][0]
+        pair = parse_output_into_pairs(out, err, 1, prefix=prefix)[0][0]
         assert pair == ('a', '1')
 
-        def prefixFunction():
+        def prefix_function():
             return 'lolsup '
-        with configureIcecreamOutput(prefix=prefixFunction):
-            with disableColoring(), captureStandardStreams() as (out, err):
+        with configure_icecream_output(prefix=prefix_function):
+            with disable_coloring(), capture_standard_streams() as (out, err):
                 ic(b)
-        pair = parseOutputIntoPairs(out, err, 1, prefix=prefixFunction())[0][0]
+        pair = parse_output_into_pairs(out, err, 1, prefix=prefix_function())[0][0]
         assert pair == ('b', '2')
 
-    def testOutputFunction(self):
+    def test_output_function(self):
         lst = []
 
-        def appendTo(s):
+        def append_to(s):
             lst.append(s)
 
-        with configureIcecreamOutput(ic.prefix, appendTo):
-            with captureStandardStreams() as (out, err):
+        with configure_icecream_output(ic.prefix, append_to):
+            with capture_standard_streams() as (out, err):
                 ic(a)
         assert not out.getvalue() and not err.getvalue()
 
-        with configureIcecreamOutput(outputFunction=appendTo):
-            with captureStandardStreams() as (out, err):
+        with configure_icecream_output(outputFunction=append_to):
+            with capture_standard_streams() as (out, err):
                 ic(b)
         assert not out.getvalue() and not err.getvalue()
 
-        pairs = parseOutputIntoPairs(out, '\n'.join(lst), 2)
+        pairs = parse_output_into_pairs(out, '\n'.join(lst), 2)
         assert pairs == [[('a', '1')], [('b', '2')]]
 
-    def testEnableDisable(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_enable_disable(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             assert ic(a) == 1
             assert ic.enabled
 
@@ -375,22 +373,22 @@ class TestIceCream(unittest.TestCase):
             assert ic.enabled
             assert ic(c) == 3
 
-        pairs = parseOutputIntoPairs(out, err, 2)
+        pairs = parse_output_into_pairs(out, err, 2)
         assert pairs == [[('a', '1')], [('c', '3')]]
 
-    def testArgToStringFunction(self):
+    def test_arg_to_string_function(self):
         def hello(obj):
             return 'zwei'
 
-        with configureIcecreamOutput(argToStringFunction=hello):
-            with disableColoring(), captureStandardStreams() as (out, err):
+        with configure_icecream_output(argToStringFunction=hello):
+            with disable_coloring(), capture_standard_streams() as (out, err):
                 eins = 'ein'
                 ic(eins)
-        pair = parseOutputIntoPairs(out, err, 1)[0][0]
+        pair = parse_output_into_pairs(out, err, 1)[0][0]
         assert pair == ('eins', 'zwei')
 
-    def testSingledispatchArgumentToString(self):
-        def argumentToString_tuple(obj):
+    def test_singledispatch_argument_to_string(self):
+        def argument_to_string_tuple(obj):
             return "Dispatching tuple!"
 
         # Prepare input and output
@@ -398,34 +396,34 @@ class TestIceCream(unittest.TestCase):
         default_output = ic.format(x)
 
         # Register
-        argumentToString.register(tuple, argumentToString_tuple)
+        argumentToString.register(tuple, argument_to_string_tuple)
         assert tuple in argumentToString.registry
-        assert str.endswith(ic.format(x), argumentToString_tuple(x))
+        assert str.endswith(ic.format(x), argument_to_string_tuple(x))
 
         # Unregister
         argumentToString.unregister(tuple)
         assert tuple not in argumentToString.registry
         assert ic.format(x) == default_output
 
-    def testSingleArgumentLongLineNotWrapped(self):
+    def test_single_argument_long_line_not_wrapped(self):
         # A single long line with one argument is not line wrapped.
         longStr = '*' * (ic.lineWrapWidth + 1)
-        with disableColoring(), captureStandardStreams() as (out, err):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic(longStr)
-        pair = parseOutputIntoPairs(out, err, 1)[0][0]
+        pair = parse_output_into_pairs(out, err, 1)[0][0]
         assert len(err.getvalue()) > ic.lineWrapWidth
         assert pair == ('longStr', ic.argToStringFunction(longStr))
 
-    def testMultipleArgumentsLongLineWrapped(self):
+    def test_multiple_arguments_long_line_wrapped(self):
         # A single long line with multiple variables is line wrapped.
         val = '*' * int(ic.lineWrapWidth / 4)
         valStr = ic.argToStringFunction(val)
 
         v1 = v2 = v3 = v4 = val
-        with disableColoring(), captureStandardStreams() as (out, err):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic(v1, v2, v3, v4)
 
-        pairs = parseOutputIntoPairs(out, err, 4)
+        pairs = parse_output_into_pairs(out, err, 4)
         assert pairs == [[(k, valStr)] for k in ['v1', 'v2', 'v3', 'v4']]
 
         lines = err.getvalue().splitlines()
@@ -435,75 +433,75 @@ class TestIceCream(unittest.TestCase):
             lines[2].startswith(' ' * len(ic.prefix)) and
             lines[3].startswith(' ' * len(ic.prefix)))
 
-    def testMultilineValueWrapped(self):
+    def test_multiline_value_wrapped(self):
         # Multiline values are line wrapped.
         multilineStr = 'line1\nline2'
-        with disableColoring(), captureStandardStreams() as (out, err):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic(multilineStr)
-        pair = parseOutputIntoPairs(out, err, 2)[0][0]
+        pair = parse_output_into_pairs(out, err, 2)[0][0]
         assert pair == ('multilineStr', ic.argToStringFunction(multilineStr))
 
-    def testIncludeContextSingleLine(self):
+    def test_include_context_single_line(self):
         i = 3
-        with configureIcecreamOutput(includeContext=True):
-            with disableColoring(), captureStandardStreams() as (out, err):
+        with configure_icecream_output(includeContext=True):
+            with disable_coloring(), capture_standard_streams() as (out, err):
                 ic(i)
 
-        pair = parseOutputIntoPairs(out, err, 1)[0][0]
+        pair = parse_output_into_pairs(out, err, 1)[0][0]
         assert pair == ('i', '3')
 
-    def testContextAbsPathSingleLine(self):
+    def test_context_abs_path_single_line(self):
         i = 3
-        with configureIcecreamOutput(includeContext=True, contextAbsPath=True):
-            with disableColoring(), captureStandardStreams() as (out, err):
+        with configure_icecream_output(includeContext=True, contextAbsPath=True):
+            with disable_coloring(), capture_standard_streams() as (out, err):
                 ic(i)
         # Output with absolute path can easily exceed line width, so no assert line num here.
-        pairs = parseOutputIntoPairs(out, err, 0)
+        pairs = parse_output_into_pairs(out, err, 0)
         assert [('i', '3')] in pairs
 
-    def testValues(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_values(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             # Test both 'asdf' and "asdf"; see
             # https://github.com/gruns/icecream/issues/53.
             ic(3, 'asdf', "asdf")
 
-        pairs = parseOutputIntoPairs(out, err, 1)
+        pairs = parse_output_into_pairs(out, err, 1)
         assert pairs == [[(None, '3'), (None, "'asdf'"), (None, "'asdf'")]]
 
-    def testIncludeContextMultiLine(self):
+    def test_include_context_multi_line(self):
         multilineStr = 'line1\nline2'
-        with configureIcecreamOutput(includeContext=True):
-            with disableColoring(), captureStandardStreams() as (out, err):
+        with configure_icecream_output(includeContext=True):
+            with disable_coloring(), capture_standard_streams() as (out, err):
                 ic(multilineStr)
 
         firstLine = err.getvalue().splitlines()[0]
-        assert lineIsContext(firstLine)
+        assert line_is_context(firstLine)
 
-        pair = parseOutputIntoPairs(out, err, 3)[1][0]
+        pair = parse_output_into_pairs(out, err, 3)[1][0]
         assert pair == ('multilineStr', ic.argToStringFunction(multilineStr))
 
-    def testContextAbsPathMultiLine(self):
+    def test_context_abs_path_multi_line(self):
         multilineStr = 'line1\nline2'
-        with configureIcecreamOutput(includeContext=True, contextAbsPath=True):
-            with disableColoring(), captureStandardStreams() as (out, err):
+        with configure_icecream_output(includeContext=True, contextAbsPath=True):
+            with disable_coloring(), capture_standard_streams() as (out, err):
                 ic(multilineStr)
 
         firstLine = err.getvalue().splitlines()[0]
-        assert lineIsAbsPathContext(firstLine)
+        assert line_is_abs_path_context(firstLine)
 
-        pair = parseOutputIntoPairs(out, err, 3)[1][0]
+        pair = parse_output_into_pairs(out, err, 3)[1][0]
         assert pair == ('multilineStr', ic.argToStringFunction(multilineStr))
-    
-    def testFormat(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+
+    def test_format(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             """comment"""; noop(); ic(  # noqa
                 'sup'); noop()  # noqa
         """comment"""; noop(); s = ic.format(  # noqa
             'sup'); noop()  # noqa
         assert s == err.getvalue().rstrip()
 
-    def testMultilineInvocationWithComments(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_multiline_invocation_with_comments(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic(  # Comment.
 
                 a,  # Comment.
@@ -514,51 +512,65 @@ class TestIceCream(unittest.TestCase):
 
                 )  # Comment.
 
-        pairs = parseOutputIntoPairs(out, err, 1)[0]
+        pairs = parse_output_into_pairs(out, err, 1)[0]
         assert pairs == [('a', '1'), ('b', '2')]
 
-    def testNoSourceAvailablePrintsValues(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_no_source_available_prints_values(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             with warnings.catch_warnings():
                 # we ignore the warning so that it doesn't interfere
                 # with parsing ic's output
                 warnings.simplefilter("ignore")
                 eval('ic(a, b)')
-                pairs = parseOutputIntoPairs(out, err, 1)
+                pairs = parse_output_into_pairs(out, err, 1)
                 self.assertEqual(pairs, [[(None, '1'), (None, "2")]])
 
-    def testNoSourceAvailablePrintsMultiline(self):
+    def test_no_source_available_prints_multiline(self):
         """
         This tests for a bug which caused only multiline prints to fail.
         """
         multilineStr = 'line1\nline2'
-        with disableColoring(), captureStandardStreams() as (out, err):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             with warnings.catch_warnings():
                 # we ignore the warning so that it doesn't interfere
                 # with parsing ic's output
                 warnings.simplefilter("ignore")
                 eval('ic(multilineStr)')
-                pair = parseOutputIntoPairs(out, err, 2)[0][0]
+                pair = parse_output_into_pairs(out, err, 2)[0][0]
                 self.assertEqual(pair, (None, ic.argToStringFunction(multilineStr)))
 
-    def testNoSourceAvailableIssuesExactlyOneWarning(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
-            with warnings.catch_warnings(record=True) as allWarnings:
+    def test_no_source_available_issues_exactly_one_warning(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
+            with warnings.catch_warnings(record=True) as all_warnings:
                 eval('ic(a)')
                 eval('ic(b)')
-                assert len(allWarnings) == 1
-                warning = allWarnings[-1]
+                assert len(all_warnings) == 1
+                warning = all_warnings[-1]
                 assert NO_SOURCE_AVAILABLE_WARNING_MESSAGE in str(warning.message)
 
-    def testSingleTupleArgument(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_single_tuple_argument(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic((a, b))
 
-        pair = parseOutputIntoPairs(out, err, 1)[0][0]
+        pair = parse_output_into_pairs(out, err, 1)[0][0]
         self.assertEqual(pair, ('(a, b)', '(1, 2)'))
 
-    def testMultilineContainerArgs(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_flat_medium_list_prints_on_one_line(self):
+        """Flat medium-sized lists should not be split one item per line."""
+        data = [1, 1, 1, 1, 1, 1, 1, 1,
+                0, 0, 0, 0, 0, 0, 0, 0,
+                0, 0, 0, 0,
+                1, 1, 1, 1, 1,
+                0, 1, 0, 1, 0, 1, 0]
+
+        with disable_coloring(), capture_standard_streams() as (out, err):
+            ic(data)
+
+        # The whole ic() call should fit on a single line.
+        self.assertEqual(len(err.getvalue().strip().splitlines()), 1)
+
+    def test_multiline_container_args(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic((a,
                 b))
             ic([a,
@@ -580,8 +592,8 @@ ic| (a,
                         [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14]]
         """.strip())
 
-        with disableColoring(), captureStandardStreams() as (out, err):
-            with configureIcecreamOutput(includeContext=True):
+        with disable_coloring(), capture_standard_streams() as (out, err):
+            with configure_icecream_output(includeContext=True):
                 ic((a,
                     b),
                    [list(range(15)),
@@ -590,7 +602,7 @@ ic| (a,
         lines = err.getvalue().strip().splitlines()
         self.assertRegex(
             lines[0],
-            r'ic\| test_icecream.py:\d+ in testMultilineContainerArgs\(\)',
+            r'ic\| test_icecream.py:\d+ in test_multiline_container_args\(\)',
         )
         self.assertEqual('\n'.join(lines[1:]), """\
     (a,
@@ -599,21 +611,21 @@ ic| (a,
      list(range(15))]: [[0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14],
                         [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14]]""")
 
-    def testMultipleTupleArguments(self):
-        with disableColoring(), captureStandardStreams() as (out, err):
+    def test_multiple_tuple_arguments(self):
+        with disable_coloring(), capture_standard_streams() as (out, err):
             ic((a, b), (b, a), a, b)
 
-        pair = parseOutputIntoPairs(out, err, 1)[0]
+        pair = parse_output_into_pairs(out, err, 1)[0]
         self.assertEqual(pair, [
             ('(a, b)', '(1, 2)'), ('(b, a)', '(2, 1)'), ('a', '1'), ('b', '2')])
 
-    def testColoring(self):
-        with captureStandardStreams() as (out, err):
+    def test_coloring(self):
+        with capture_standard_streams() as (out, err):
             ic({1: 'str'})  # Output should be colored with ANSI control codes.
 
-        assert hasAnsiEscapeCodes(err.getvalue())
+        assert has_ansi_escape_codes(err.getvalue())
 
-    def testConfigureOutputWithNoParameters(self):
+    def test_configure_output_with_no_parameters(self):
         with self.assertRaises(TypeError):
             ic.configureOutput()
 
@@ -623,14 +635,14 @@ ic| (a,
         test2 = r"A\veryvery\long\path\to\no\even\longer\HelloWorld _01_Heritisfinallythe file.file"
         test3 = "line\nline"
 
-        with disableColoring(), captureStandardStreams() as (_, err):
+        with disable_coloring(), capture_standard_streams() as (_, err):
             ic(test1)
             curr_res = err.getvalue().strip()
             expected = r"ic| test1: 'A\\veryvery\\long\\path\\to\\no\\even\\longer\\HelloWorld _01_Heritisfinallythe file.file'"
             self.assertEqual(curr_res, expected)
             del curr_res, expected
 
-        with disableColoring(), captureStandardStreams() as (_, err):
+        with disable_coloring(), capture_standard_streams() as (_, err):
             ic(test2)
             curr_res = err.getvalue().strip()
             # expected = r"ic| test2: 'A\\veryvery\\long\\path\\to\\no\\even\\longer\\HelloWorld _01_Heritisfinallythe file.file'"
@@ -638,10 +650,50 @@ ic| (a,
             self.assertEqual(curr_res, expected)
             del curr_res, expected
 
-        with disableColoring(), captureStandardStreams() as (_, err):
+        with disable_coloring(), capture_standard_streams() as (_, err):
             ic(test3)
             curr_res = err.getvalue().strip()
             expected = r"""ic| test3: '''line
             line'''"""
             self.assertEqual(curr_res, expected)
             del curr_res, expected
+
+    def test_sympy_dict_keys_do_not_crash(self):
+        """Regression: ic() must not raise when dict keys are SymPy symbols."""
+
+        try:
+            import sympy as sp
+        except Exception:
+            self.skipTest("sympy not installed")
+
+        x, y = sp.symbols("x y")
+        d = {x: "hello", y: "world"}
+
+        with disable_coloring(), capture_standard_streams() as (out, err):
+            # If the bug regresses, this line raises TypeError.
+            ic(d)
+
+        s = err.getvalue().strip()
+        # Basic sanity checks without assuming exact formatting or ordering.
+        self.assertIn("ic|", s)
+        self.assertIn("hello", s)
+        self.assertIn("world", s)
+
+    def test_sympy_solve_result_does_not_crash(self):
+        """Regression: ic() must handle SymPy solve() outputs."""
+
+        try:
+            import sympy as sp
+        except Exception:
+            self.skipTest("sympy not installed")
+
+        x, y = sp.symbols("x y")
+        res = sp.solve([x + 2, y - 2])   # list/dict of symbolic items
+
+        with disable_coloring(), capture_standard_streams() as (out, err):
+            ic(res)
+
+        s = err.getvalue()
+        self.assertIn("ic|", s)
+        # Don’t assert exact text; just ensure something printed.
+        self.assertTrue(len(s) > 0)
